summaryrefslogtreecommitdiffstats
path: root/js
diff options
context:
space:
mode:
authormkanat%bugzilla.org <>2009-05-22 02:14:24 +0200
committermkanat%bugzilla.org <>2009-05-22 02:14:24 +0200
commit5c8a0d34a1cc70ff31f11c7904b718d8784c616d (patch)
treeb9d4ee181178bf53506cc5ef97fbbafcf047f802 /js
parentd04cb25873a44ba7d0eb9e8580180dd4a64e8cef (diff)
downloadbugzilla-5c8a0d34a1cc70ff31f11c7904b718d8784c616d.tar.gz
bugzilla-5c8a0d34a1cc70ff31f11c7904b718d8784c616d.tar.xz
Bug 482556: Put "Forgot Password" in the header and footer so people can still f
ind it Patch by Max Kanat-Alexander <mkanat@bugzilla.org> r=LpSolit, a=LpSolit
Diffstat (limited to 'js')
-rw-r--r--js/global.js61
1 files changed, 56 insertions, 5 deletions
diff --git a/js/global.js b/js/global.js
index de3d7915d..77e40d4c8 100644
--- a/js/global.js
+++ b/js/global.js
@@ -1,4 +1,4 @@
-/* The contents of this file are subject to the Mozilla Public
+/* The contents of this file are subject to the Mozilla Public
* License Version 1.1 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy of
* the License at http://www.mozilla.org/MPL/
@@ -10,25 +10,76 @@
*
* The Original Code is the Bugzilla Bug Tracking System.
*
-* Contributor(s): Guy Pyrzak <guy.pyrzak@gmail.com>
+* Contributor(s):
+* Guy Pyrzak <guy.pyrzak@gmail.com>
+* Max Kanat-Alexander <mkanat@bugzilla.org>
*
*/
var mini_login_constants;
+function show_mini_login_form( suffix ) {
+ var login_link = document.getElementById('login_link' + suffix);
+ var login_form = document.getElementById('mini_login' + suffix);
+ var account_container = document.getElementById('new_account_container'
+ + suffix);
+
+ YAHOO.util.Dom.addClass(login_link, 'bz_default_hidden');
+ YAHOO.util.Dom.removeClass(login_form, 'bz_default_hidden');
+ YAHOO.util.Dom.addClass(account_container, 'bz_default_hidden');
+ return false;
+}
+
+function hide_mini_login_form( suffix ) {
+ var login_link = document.getElementById('login_link' + suffix);
+ var login_form = document.getElementById('mini_login' + suffix);
+ var account_container = document.getElementById('new_account_container'
+ + suffix);
+
+ YAHOO.util.Dom.removeClass(login_link, 'bz_default_hidden');
+ YAHOO.util.Dom.addClass(login_form, 'bz_default_hidden');
+ YAHOO.util.Dom.removeClass(account_container, 'bz_default_hidden');
+ return false;
+}
+
+function show_forgot_form( suffix ) {
+ var forgot_link = document.getElementById('forgot_link' + suffix);
+ var forgot_form = document.getElementById('forgot_form' + suffix);
+ var login_container = document.getElementById('mini_login_container'
+ + suffix);
+ YAHOO.util.Dom.addClass(forgot_link, 'bz_default_hidden');
+ YAHOO.util.Dom.removeClass(forgot_form, 'bz_default_hidden');
+ YAHOO.util.Dom.addClass(login_container, 'bz_default_hidden');
+ return false;
+}
+
+function hide_forgot_form( suffix ) {
+ var forgot_link = document.getElementById('forgot_link' + suffix);
+ var forgot_form = document.getElementById('forgot_form' + suffix);
+ var login_container = document.getElementById('mini_login_container'
+ + suffix);
+ YAHOO.util.Dom.removeClass(forgot_link, 'bz_default_hidden');
+ YAHOO.util.Dom.addClass(forgot_form, 'bz_default_hidden');
+ YAHOO.util.Dom.removeClass(login_container, 'bz_default_hidden');
+ return false;
+}
+
function init_mini_login_form( suffix ) {
var mini_login = document.getElementById('Bugzilla_login' + suffix );
var mini_password = document.getElementById('Bugzilla_password' + suffix );
var mini_dummy = document.getElementById(
'Bugzilla_password_dummy' + suffix);
// If the login and password are blank when the page loads, we display
// "login" and "password" in the boxes
if (mini_login.value == "" && mini_password.value == "") {
mini_login.value = mini_login_constants.login;
YAHOO.util.Dom.addClass(mini_login, "bz_mini_login_help");
YAHOO.util.Dom.addClass(mini_password, 'bz_default_hidden');
YAHOO.util.Dom.removeClass(mini_dummy, 'bz_default_hidden');
}
+ else {
+ show_mini_login_form(suffix);
+ }
}
// Clear the words "login" and "password" from the form when you click
@@ -51,8 +102,8 @@ function mini_login_on_focus( suffix ) {
function check_mini_login_fields( suffix ) {
var mini_login = document.getElementById('Bugzilla_login' + suffix );
var mini_password = document.getElementById('Bugzilla_password' + suffix );
- if( ( mini_login.value != "" && mini_password.value != "" ) &&
- mini_login.value != mini_login_constants.login)
+ if( (mini_login.value != "" && mini_password.value != "")
+ && mini_login.value != mini_login_constants.login )
{
return true;
}
@@ -10,25 +10,76 @@
'Bugzilla_password_dummy' + suffix);
// If the login and password are blank when the page loads, we display
- // "login" and "password" in the boxes
+ // "login" and "password" in the boxes by default.
if (mini_login.value == "" && mini_password.value == "") {
mini_login.value = mini_login_constants.login;